pub struct ClientSmeGetScheduledScanEnabledResponse {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for ClientSmeGetScheduledScanEnabledResponse
impl Clone for ClientSmeGetScheduledScanEnabledResponse
Sourcefn clone(&self) -> ClientSmeGetScheduledScanEnabledResponse
fn clone(&self) -> ClientSmeGetScheduledScanEnabledResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<ClientSmeGetScheduledScanEnabledResponse, D> for ClientSmeGetScheduledScanEnabledResponse
impl<D: ResourceDialect> Decode<ClientSmeGetScheduledScanEnabledResponse, D> for ClientSmeGetScheduledScanEnabledResponse
Sourceimpl<D: ResourceDialect> Encode<ClientSmeGetScheduledScanEnabledResponse, D> for &ClientSmeGetScheduledScanEnabledResponse
impl<D: ResourceDialect> Encode<ClientSmeGetScheduledScanEnabledResponse, D> for &ClientSmeGetScheduledScanEnabledResponse
Sourceimpl<D: ResourceDialect, T0: Encode<bool, D>> Encode<ClientSmeGetScheduledScanEnabledResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<bool, D>> Encode<ClientSmeGetScheduledScanEnabledResponse, D> for (T0,)
Sourceimpl Ord for ClientSmeGetScheduledScanEnabledResponse
impl Ord for ClientSmeGetScheduledScanEnabledResponse
Sourcefn cmp(&self, other: &ClientSmeGetScheduledScanEnabledResponse) -> Ordering
fn cmp(&self, other: &ClientSmeGetScheduledScanEnabledResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClientSmeGetScheduledScanEnabledResponse
impl PartialEq for ClientSmeGetScheduledScanEnabledResponse
Sourcefn eq(&self, other: &ClientSmeGetScheduledScanEnabledResponse) -> bool
fn eq(&self, other: &ClientSmeGetScheduledScanEnabledResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClientSmeGetScheduledScanEnabledResponse
impl PartialOrd for ClientSmeGetScheduledScanEnabledResponse
Sourceimpl TypeMarker for ClientSmeGetScheduledScanEnabledResponse
impl TypeMarker for ClientSmeGetScheduledScanEnabledResponse
Sourcetype Owned = ClientSmeGetScheduledScanEnabledResponse
type Owned = ClientSmeGetScheduledScanEnabledResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ClientSmeGetScheduledScanEnabledResponse
impl ValueTypeMarker for ClientSmeGetScheduledScanEnabledResponse
Sourcetype Borrowed<'a> = &'a ClientSmeGetScheduledScanEnabledResponse
type Borrowed<'a> = &'a ClientSmeGetScheduledScanEnabledResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for ClientSmeGetScheduledScanEnabledResponse
impl Eq for ClientSmeGetScheduledScanEnabledResponse
impl Persistable for ClientSmeGetScheduledScanEnabledResponse
impl StructuralPartialEq for ClientSmeGetScheduledScanEnabledResponse